<script>

var profileType = "noprofile";
var hostname = null;
var profileName = null;
var serverName = null;
var adminPort = null;
var defaultPort = null;
var isServerStarted = false;

var adminConsole = null;
var processCenterConsole = null;
var businessSpaceConsole = null;
var ivtCommand = null;

var serverPollInterval = parseInt(top.property("serverPollInterval"));
var serverPollTimeout = parseInt(top.property("serverPollTimeout"));
var serverPollFirstCheckInterval = parseInt(top.property("serverPollFirstCheckInterval"));


var firstRun = true;

/**
 * Execute at startup to determine profile type and kickoff server interval check
 */
function launchpadStartup(){

    // Get WAS_HOME
    var wasHome = top.getNativeFileName(top.getEnv("WAS_HOME"));
    top.logDebug("Environment WAS_HOME: " + wasHome);
    
    // Determine starting dir
    var launchDir = top.getNativeFileName(top.STARTINGDIR);
    top.logDebug("FirstSteps started from: " + launchDir);
    
	var firstStepsDir = null;
	
	// Set special WBM settings
	if (top.diskLabel.edition == 'WBM') {
		firstStepsDir = launchDir;
		top.ivtCommand = "wbmIvt";
	}
	else {
	    firstStepsDir = top.getNativeFileName(launchDir + "/../");
		if (top.diskLabel.edition == 'BPMEXP' || top.diskLabel.edition == 'BPMSTD') {
			top.ivtCommand = "wasIvt";
		}
		else {
			top.ivtCommand = "wbiIvt";
		}
	}
	
    top.logDebug("FirstSteps directory identified as: " + firstStepsDir);
    
    // Check for config directory to determine profile type
    var configDir = top.getNativeFileName(firstStepsDir + "/../config");
    top.logDebug("Config Directory identified as: " + configDir);
    
    if (!top.directoryExists(NO_DISKID, configDir)) {
        top.logDebug("Config Directory did not exist, setting profileType to 'noprofile'");
        top.profileType = "noprofile";
		top.makeTempCopyrightFile();
        return;
    }
    else {
    
        // Get the profile name
        top.logDebug("Config Directory exists, determining profile name");

        var configRootDir = top.getEnv("CONFIG_ROOT");
        top.logDebug("Config Root directory identified as: " + configRootDir);
        
        var index = configRootDir.lastIndexOf(top.getNativeFileSeparator());
	var profileDir = configRootDir.substring(0, index);
        top.logDebug("Profile directory identified as: " + profileDir);
        
        index = profileDir.lastIndexOf(top.getNativeFileSeparator());
        top.profileName = profileDir.substring(index + 1);
        top.logDebug("Profile Name identified as: " + top.profileName);
        
        // Get the profileRegistry.xml file and discover the profile type
        var profileRegistryFile = top.getNativeFileName(wasHome + "/properties/profileRegistry.xml")
        top.logDebug("Profile Registry file identified as: " + profileRegistryFile);
        
        if (!top.fileExists(profileRegistryFile)) {
            top.logDebug("Profile Registry file does not exist");
            top.profileType = "noprofile";
			top.makeTempCopyrightFile();
            return;
        }
        
        var profileRegistryXml = top.getXmlDoc(profileRegistryFile);
        var profiles = profileRegistryXml.getElementsByTagName("profile");
        var template = null;
        
        for (i = 0; i < profiles.length; i++) {
            var name = profiles[i].getAttribute("name");
            if (name === top.profileName) {
                top.logDebug("Found profile: " + name);
                var templatePath = profiles[i].getAttribute("template");
                var index = templatePath.lastIndexOf(top.getNativeFileSeparator());
                top.profileType = templatePath.substring(index + 1);
                top.logDebug("Found profileType: " + top.profileType);
                if (top.profileType == "managed") {
                    return;
                }
                break;
            }
            else {
                top.logDebug("Skipping profile: " + name);
            }
        }
        
        if (top.profileType == "noprofile") {
            top.logDebug("Unable to find template type");
			top.makeTempCopyrightFile();
            return;
        }
        
        // Get the cell and node names
        var wasCell = top.getNativeFileName(top.getEnv("WAS_CELL"));
        top.logDebug("Environment WAS_CELL: " + wasCell);
        
        var wasNode = top.getNativeFileName(top.getEnv("WAS_NODE"));
        top.logDebug("Environment WAS_NODE: " + wasNode);
        
        // Get the serverindex.xml file for the server ports
        var serverIndexFile = top.getNativeFileName(configDir + "/cells/" + wasCell + "/nodes/" + wasNode + "/serverindex.xml");
        if (!top.fileExists(serverIndexFile)) {
            top.logDebug("Server Index file does not exist");
            top.profileType = "noprofile";
			top.makeTempCopyrightFile();
            return;
        }
        
        top.logDebug("Server Index file found to be: " + serverIndexFile);
        var serverIndexXml = top.getXmlDoc(serverIndexFile);
        
        // We will only support single server
        var serverIndex = serverIndexXml.getElementsByTagName("serverindex:ServerIndex")[0];
        top.hostname = serverIndex.getAttribute("hostName");
        top.logDebug("Hostname found to be: " + top.hostname);
        
        var serverEntry = serverIndex.getElementsByTagName("serverEntries")[0];
        top.serverName = serverEntry.getAttribute("serverName");
        var endpoints = serverEntry.getElementsByTagName("specialEndpoints");
        
        for (i = 0; i < endpoints.length; i++) {
            var name = endpoints[i].getAttribute("endPointName");
            if (name === "WC_adminhost") {
                top.adminPort = endpoints[i].getElementsByTagName("endPoint")[0].getAttribute("port");
                top.logDebug("Found WC_adminhost: " + adminPort);
                top.adminConsole = "http://" + top.hostname + ":" + top.adminPort + "/ibm/console";
            }
            else 
                if (name === "WC_defaulthost") {
                    defaultPort = endpoints[i].getElementsByTagName("endPoint")[0].getAttribute("port");
                    top.logDebug("Found WC_defaulthost: " + defaultPort);
					top.processCenterConsole = "http://" + top.hostname + ":" + top.defaultPort + "/ProcessCenter";
					top.businessSpaceConsole = "http://" + top.hostname + ":" + top.defaultPort + "/BusinessSpace";
                }
                else {
                    top.logDebug("Skipping endpoint: " + name);
                }
        }
        
        // If we can't find an admin port, that is a problem
        if (adminPort == null) {
            top.logDebug("Unable to find admin port");
            top.profileType = "noprofile";
			top.makeTempCopyrightFile();
            return;
        }
        
        // If we can't find an default port, on a default, BPMEXP, BPMSTD, or BPMSTD install, that is a problem
        if (defaultPort == null && top.profileType == "default" && (top.diskLabel.edition == "BPMEXP" || top.diskLabel.edition == "BPMSTD" || top.diskLabel.edition == "BPMPC")) {
            top.logDebug("Unable to find default port");
            top.profileType = "noprofile";
			top.makeTempCopyrightFile();
            return;
        }
    }
    
    top.updateServerStatus();
}

/**
 * Pings the server and then updates the UI to match the server settings
 */
function updateServerStatus(){

	// Temp fix for 107527 - will have all links shown regardless of server status
	return;

	// If the page has not yet loaded, rerun when it is available
    if (!top.navigationLoaded) {
        window.setTimeout("top.updateServerStatus()", top.serverPollFirstCheckInterval);
		return;
    }
    
    top.pingServer();
    
    // Show server started menu items and hide server stopped menu items
    if (isServerStarted) {
        top.toggleMenu("startServer", false);
        top.toggleMenu("stopServer", true);
        top.toggleMenu("adminConsole", true);
		top.toggleMenu("processCenter", true);
		top.toggleMenu("bspace", true);
		if (top.diskLabel.edition != 'WBM') {
			top.toggleSection("performOptionalActionsSection", true);	
		}
    }
    // Hide server started menu items and show server stopped menu items
    else {
        top.toggleMenu("stopServer", false);
        top.toggleMenu("adminConsole", false);
		top.toggleMenu("processCenter", false);
		top.toggleMenu("bspace", false);
		if (top.diskLabel.edition != 'WBM') {
			top.toggleSection("performOptionalActionsSection", false);
		}
        top.toggleMenu("startServer", true);
    }
	
	if (top.firstRun) {
		top.firstRun = false;
		setInterval("top.updateServerStatus();", top.serverPollInterval);
	}
}

/**
 * Toggles the visibility of the given menu item
 */
function toggleMenu(menu, show){

    var menuLink = top.navigationDocument.getElementById(menu + "ActionContainer");
    
    if (!menuLink) {
        top.logDebug("Could not find menu link: " + menu);
        return;
    }
    
	var menuDesc = top.navigationDocument.getElementById(menu + "ActionDescription");
	if (!menuDesc) {
		menuDesc = menuLink.previousSibling;
	}
    
    if (!menuDesc) {
        top.logDebug("Could not find menu description: " + menu);
        return;
    }
    
    var styleDisplay = show ? "" : "none";
    menuLink.style.display = styleDisplay;
    menuDesc.style.display = styleDisplay;
}

/**
 * Toggles the visibility of the given section
 */
function toggleSection(section, show){

    var sectionContainer = top.navigationDocument.getElementById(section + "SectionContainer");
    
    if (!sectionContainer) {
        top.logDebug("Could not find section container: " + section);
        return;
    }
    
    var sectionIcon = top.navigationDocument.getElementById(section + "SectionIconContainer");
    
    if (!sectionIcon) {
        top.logDebug("Could not find section icon: " + section);
        return;
    }
    
    var styleDisplay = show ? "" : "none";
    sectionContainer.style.display = styleDisplay;
    sectionIcon.style.display = styleDisplay;
}

function runPmt() {
	//if (top.isPmtRunning()) {
	//	var buttonText = top.property("pmt.button");
	//	top.showDialog(top.property("pmt.dialog"), { id: "pmtRunningDialogId", buttons: [{ id: "pmtRunningDialogOkButton", name: buttonText, value: buttonText, onclick: "top.showDialog('pmtRunningDialogId', false);" } ] });	
	//}
	//else {
	//defect 155809, Once the PMT is started, the wct.workspace.lock file is always there. 
	//so remove if condition and call PMT anyway. PMT itself will help to decide only one is running.
		runProgram(NO_DISKID,command('PMT'), BACKGROUND, VISIBLE, this);	
	//}
}

function runIvt() {
	var link = top.navigationDocument.getElementById("ivtActionLink");
	var profileTemplateType;
	if (top.profileType == "management") {
		profileTemplateType = 2;  // dmgr
	}
	else if (top.profileType == "managed") {
		profileTemplateType = 3;  // custom
	}
	else {
		profileTemplateType = 1;  // application server
	}
	var subprogram = command(top.ivtCommand, top.serverName, top.profileName, profileTemplateType);
	runProgram(NO_DISKID, command('terminal', top.getPropertyAlternateLocale('ivt.desc', 'en', 'global.properties'), subprogram), BACKGROUND, HIDDEN, link);	
}

function runStartServer() {
	var link = top.navigationDocument.getElementById("startServerActionLink");
	var subprogram = command('runStartServer', top.serverName)
	runProgram(NO_DISKID, command('terminal', top.getPropertyAlternateLocale('startServer.link', 'en', 'global.properties'), subprogram), BACKGROUND, HIDDEN, link);	
}

function runStopServer() {
	var link = top.navigationDocument.getElementById("stopServerActionLink");
	var subprogram = command('runStopServer', top.serverName);
	runProgram(NO_DISKID, command('terminal', top.getPropertyAlternateLocale('stopServer.link', 'en', 'global.properties'), subprogram), BACKGROUND, HIDDEN, link);	
}

function runShowcase() {
	var subprogram = command('runShowcase');
	runProgram(NO_DISKID, command('terminal', top.getPropertyAlternateLocale('showcase.link', 'en', 'global.properties'), subprogram), BACKGROUND, HIDDEN, this);	
}

/****************** Log file methods  **********************/

function logDebug(message){
    var now = new Date().getTime();
    message = "" + now + " " + message;
    
    if (top.isWindows()) {
        message += "\r\n";
    }
    else {
        message += "\n";
    }
    
    top.writeTextFile(top.getTempFilename("firststeps.log"), message, true, "UTF-8");
}

/**
 * Returns OS correct path to temp file that starts with temp dir and ends with filename
 **/
function getTempFilename(filename){
    return top.getNativeFileName(top.getEnv("LaunchPadTemp") + "/" + filename);
}

function makeTempCopyrightFile() {

	// Read the copyright properties file
	secureReadPropertiesFile(new Function('return window'), top.STARTINGDIR + top.RELATIVEDIR, "copyright.properties", document.properties, findProperty('fallBackLocale', self, 'en'));
	
	// Ready template copyright file
	var copyrightText = top.readTextFile(top.getNativeFileName(top.STARTINGDIR + "/launchpad/content/copyright.html"), "UTF-8");
	
	var newCopyrightText = "";
	var startIndex = 0;
	var endIndex = 0;
	
	while(true) {
		startIndex = copyrightText.indexOf(property("code.start"));
		top.logDebug("Found start at position: " + startIndex);
		
		if (startIndex == -1) {
			break;
		}
		
		var pre = copyrightText.substring(0, startIndex);
		newCopyrightText = newCopyrightText.concat(pre);
		top.logDebug("Pre-text is: " + pre);
		
		copyrightText = copyrightText.substring(startIndex + 3);
		
		endIndex = copyrightText.indexOf(property("code.end"));
		top.logDebug("Found end at position: " + endIndex);
		
		if (endIndex == -1) {
			continue;
		}
		
		var code = copyrightText.substring(0, endIndex);
		top.logDebug("Code is: " + code);
		var result = eval(code);
		top.logDebug("Result is: " + result);
		
		newCopyrightText = newCopyrightText.concat(result);
		
		copyrightText = copyrightText.substring(endIndex + 2);
	}
	
	newCopyrightText = newCopyrightText.concat(copyrightText);
	
	// Write updated template
	top.writeTextFile(top.getTempFilename("copyright.html"), newCopyrightText, false, "UTF-8");
}

/**********************************************************/

/**
 * Returns an xmldoc handle for the given file
 */
function getXmlDoc(filename){
    var xmlDoc = null;
    if (window.ActiveXObject) { // code for IE
        xmlDoc = new ActiveXObject("Microsoft.XMLDOM");
    }
    else 
        if (document.implementation.createDocument) { // code for Mozilla, Firefox, Opera, etc.
            xmlDoc = document.implementation.createDocument("", "", null);
        }
        else {
            alert('Your browser cannot handle this script');
        }
    
    if (xmlDoc != null) {
        xmlDoc.async = false;
        xmlDoc.load(filename);
        return xmlDoc;
    }
}

/**
 * Sets the status of the server after the results of a ping
 */
function pingServer(){

    var xmlhttp = null;
    if (window.XMLHttpRequest) { // code for IE7+, Firefox, Chrome, Opera, Safari
        xmlhttp = new XMLHttpRequest();
    }
    else { // code for IE6, IE5
        xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
    }
    
    if (xmlhttp == null) {
        top.isServerStarted = false;
        return;
    }
    
    var readyStateChange = function(){
        if (xmlhttp.readyState == 4) {
            if (xmlhttp.status == 404 || xmlhttp.status == 0 || xmlhttp.status > 12000) { // Linux sometimes uses 0, IE has some 12XXX codes for cannot connect to internet failures
                top.isServerStarted = false;
                return;
            }
            else {
                top.isServerStarted = true;
                return;
            }
        }
    }
    
    // Adds a random number to prevent result caching
    xmlhttp.open("GET", top.adminConsole + "?random=" + Math.random(), true);
	xmlhttp.onreadystatechange = readyStateChange;
    xmlhttp.timeout = top.serverPollTimeout;
    xmlhttp.ontimeout = function(){
        top.isServerStarted = false;
        return;
    }
    xmlhttp.send();
}

function isPmtRunning() {
	
	var lockExists = false;
	var lockFile = null;
	
	if (top.isWindows()) {
		var localAppData = top.getNativeFileName(top.getEnv("LOCALAPPDATA"));
		top.logDebug("LOCALAPPDATA: " + localAppData);
		lockFile = localAppData + "\\IBM\\WebSphere\\AppServer\\workspaces\\WCT8\\wct.workspace.lock";
	}
	else {
		var homeDir = top.getNativeFileName(top.getEnv("HOME"));
		top.logDebug("HOME: " + homeDir);
		lockFile = homeDir + "/.ibm/WebSphere/AppServer/workspaces/WCT8/wct.workspace.lock";
	}
	
	top.logDebug("PMT lockfile: " + lockFile);
	lockExists = top.fileExists(lockFile);
	top.logDebug("Does PMT lockfile exist?: " + lockExists);
	return lockExists;
}

var userSecurityCheck = new Function('return window');

/****************** Code Provided by Common Launchpad Team to fix Mocked Translation Issue *************************/
function formatmsg(template){
    try {
        var args = arguments;
        var msg = template;
        if (typeof msg == "string" && typeof arguments[1] != "undefined" && arguments[1] != null) {
            if (typeof arguments[1] != "string") {
                args = arguments[1];
            }
            for (var i = 1; i < args.length; i++) {
                if ((typeof args[i] != "undefined") && args[i] != null) {
                    var ndx = 0;
                    do {
                        ndx = msg.indexOf("%" + i, ndx);
                        if (ndx >= 0) {
                            var replacement = args[i].toString();
                            msg = msg.substring(0, ndx) + replacement + msg.substring(ndx + 2);
                            ndx += replacement.length;
                        }
                    }
                    while (ndx >= 0);
                }
            }
        }
        return msg;
    } 
    catch (e) {
        top.logException(e, arguments);
    }
    return top.UNDEFINED;
}

/******************* END code provided by Launchpad team *******************************/

//Define user functions below
function promptForInstaller(startingDir, prompt, diskValidator, command, referenceFile, relativePath){

    var keepLooping = true;
    var cdLocation = startingDir;
    relativePath = relativePath[0];
    
    if (command.length < 1) {
        return;
    }
    var installProgram = cdLocation + relativePath + command[0];
    var uniqueId = cdLocation + relativePath + referenceFile;
    while (keepLooping) {
        //Check to see if the file already in the cd rom. myCommand should be defined in the appropriate properties file
        if (clientFileExists(NO_DISKID, installProgram) && diskValidator(uniqueId)) {
            keepLooping = false;
        }
        else { //if we can't find it, ask the user for the appropriate location
            cdLocation = top.modalPromptWithBrowse(property('promptTitle'), prompt, cdLocation, top.isDirOK, 450, 170);
            if (cdLocation != null) { //format the path
                //The validaty of the CD will be verified on the next iteration
                if (cdLocation.substring(cdLocation.length - 1) != '/' && cdLocation.substring(cdLocation.length - 1) != '\\') {
                    if (top.OSTYPE == "windows") {
                        cdLocation = cdLocation + '\\';
                    }
                    else {
                        cdLocation = cdLocation + '/';
                    }
                }
                installProgram = cdLocation + command[0];
                uniqueId = cdLocation + referenceFile;
                //User canceled
            }
            else {
                return;
            }
        }
    }
    command[0] = installProgram;
    runProgram(null, command, BACKGROUND, VISIBLE, this);
}

</script>

